Summary:        The rust toolchain installer
Name:           rustup
Version:        1.25.1
Release:        6%{?dist}
License:        Apache-2.0 OR MIT
URL:            https://github.com/rust-lang/rustup
Source0:        %{version}.tar.gz
# download with `cargo vendor` with cargo.toml, then package them up with `tar jzvf`
Source1:        rustup-1.25.1-vendor.tar.bz2

BuildRequires:  cargo
BuildRequires:  pkgconfig(openssl)
Requires:       gcc
Conflicts:      rust cargo clippy rust-analyzer rust-gdb rust-lldb rustfmt

%description
This package provides a tool to manager user Rust toolchains, enabling you to easily switch 
between stable, beta, and nightly compilers and keep them updated.

%prep
%autosetup

tar -jxf %{SOURCE1}

rm .cargo/config
cat > .cargo/config.toml <<EOF
[source.crates-io]
replace-with = "vendored-sources"

[source."https://github.com/rbtcollins/home"]
git = "https://github.com/rbtcollins/home"
rev = "a243ee2fbee6022c57d56f5aa79aefe194eabe53"
replace-with = "vendored-sources"

[source.vendored-sources]
directory = "vendor"

EOF

%build
cargo build --release --offline --bin rustup-init

%install
install -D -d -m 0755 %{buildroot}%{_bindir}
install -m 0755 %{_builddir}/%{name}-%{version}/target/release/rustup-init %{buildroot}%{_bindir}/rustup
# rustup-init and rustup are the same binary, but the binary behaves differently depending on its name.
# rustup-init should only be called once and takes care of the initial setup, including setting PATH,
# modifying .bashrc etc. 
# rustup can be used the entire time and only manages toolchains. 
#
# proxy list: https://github.com/rust-lang/rustup/blob/master/src/lib.rs#L21
ln -sf rustup %{buildroot}%{_bindir}/rustc
ln -sf rustup %{buildroot}%{_bindir}/rustdoc
ln -sf rustup %{buildroot}%{_bindir}/cargo
ln -sf rustup %{buildroot}%{_bindir}/rust-analyzer
ln -sf rustup %{buildroot}%{_bindir}/rust-lldb
ln -sf rustup %{buildroot}%{_bindir}/rust-gdb
ln -sf rustup %{buildroot}%{_bindir}/cargo-clippy
ln -sf rustup %{buildroot}%{_bindir}/clippy-driver
ln -sf rustup %{buildroot}%{_bindir}/rustfmt
ln -sf rustup %{buildroot}%{_bindir}/cargo-fmt

install -D -d -m 0755 %{buildroot}%{_datadir}/bash-completion/completions
ls %{buildroot}%{_bindir}
ls %{buildroot}%{_bindir}/rustup
%{buildroot}%{_bindir}/rustup completions bash > %{buildroot}%{_datadir}/bash-completion/completions/rustup
%{buildroot}%{_bindir}/rustup completions bash cargo > %{buildroot}%{_datadir}/bash-completion/completions/cargo
install -D -d -m 0755 %{buildroot}%{_datadir}/zsh/site-functions
%{buildroot}%{_bindir}/rustup completions zsh > %{buildroot}%{_datadir}/zsh/site-functions/_rustup
%{buildroot}%{_bindir}/rustup completions zsh cargo > %{buildroot}%{_datadir}/zsh/site-functions/_cargo

%files
%{_bindir}/rustup
# %%{_bindir}/rustup-init
%{_bindir}/rustc
%{_bindir}/rustdoc
%{_bindir}/cargo
%{_bindir}/rust-analyzer
%{_bindir}/rust-lldb
%{_bindir}/rust-gdb
%{_bindir}/cargo-clippy
%{_bindir}/clippy-driver
%{_bindir}/rustfmt
%{_bindir}/cargo-fmt
%{_datadir}/bash-completion/completions/cargo
%{_datadir}/bash-completion/completions/rustup
%dir %{_datadir}/zsh
%dir %{_datadir}/zsh/site-functions
%{_datadir}/zsh/site-functions/_rustup
%{_datadir}/zsh/site-functions/_cargo

%changelog
* Mon Jul 17 2023 Wang Guodong <gordonwwang@tencent.com> - 1.25.1-6
- Rebuilt for rust 1.69.0

* Mon May 22 2023 Wang Guodong <gordonwwang@tencent.com> - 1.25.1-5
- add binaries which rustup will proxy.

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.25.1-4
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.25.1-3
- Rebuilt for OpenCloudOS Stream 23

* Thu Dec 8 2022 Wang Guodong <gordonwwang@tencent.com> - 1.25.1-2
- rebuild for cargo-1.64.0(rust-1.64.0).

* Thu Dec 1 2022 Wang Guodong <gordonwwang@tencent.com> - 1.25.1-1
- package init.